<?php
/**
 * Header template for our theme
 *
 * Displays all of the <head> section and everything up till <div id="main">.
 *
 * @package Up_Front_WP
 * @since Up Front WP 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
  <head>
    <meta charset="<?php bloginfo( 'charset' ); ?>">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <?php if ( get_theme_mod( 'responsive_layout', 1 ) ) : ?>
      <meta name="viewport" content="width=device-width, initial-scale=1">
    <?php endif; ?>
    
	<?php
	  /*
	   * Always have wp_head() just before the closing </head>
	   * tag of your theme, or you will break many plugins, which
	   * generally use this hook to add elements to <head> such
	   * as styles, scripts, and meta tags.
	   */
	  wp_head(); 
    ?>
  </head>
  <body <?php body_class(); ?>>
		<header class="clearfix">
		    <div class="logo col-md-3"><h2 class="logo-text"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h2></div>
            <nav class="clearfix">
            <?php
			    wp_nav_menu( array( 
				  'theme_location' => 'primary',
				  'container' => '',
				  'menu_class' => 'clearfix',
				  'echo' => true,
				  'depth' => 0,
                'fallback_cb'       => 'up_front_wp_bootstrap_navwalker::fallback',
                'walker'            => new up_front_wp_bootstrap_navwalker()
				  ) 
			    );
			?>
        </nav>
        <div class="pullcontainer">
        <a href="#" id="pull"><i class="fa fa-bars fa-2x"></i></a>
        </div>
        <div class="clearfix"></div>
        <?php if ( ! is_page_template( 'page-templates/front-page.php' ) || is_home() ) : ?>
	<?php $header_image = get_header_image(); ?>
        <div class="<?php if ( get_theme_mod( 'header_width' ) == 'narrow' ) : ?>container header narrow<?php else: ?>container-fluid header fluid<?php endif; ?>">
			<?php if ( get_header_image() && display_header_text() ) : ?>
              <div class="<?php if ( get_theme_mod( 'header_width' ) == 'narrow' ) : ?>narrow<?php else: ?>full-width<?php endif; ?> blog-header has-image has-text">
		    <?php elseif ( get_header_image() && !display_header_text() ) : ?>
		      <div class="<?php if ( get_theme_mod( 'header_width' ) == 'narrow' ) : ?>narrow<?php else: ?>full-width<?php endif; ?> blog-header has-image no-text">  
			<?php elseif ( !get_header_image() && display_header_text() ) : ?>
		      <div class="<?php if ( get_theme_mod( 'header_width' ) == 'narrow' ) : ?>narrow<?php else: ?>full-width<?php endif; ?> blog-header no-image has-text">    
		    <?php elseif ( !get_header_image() && !display_header_text() ) : ?>
              <div class="<?php if ( get_theme_mod( 'header_width' ) == 'narrow' ) : ?>narrow<?php else: ?>full-width<?php endif; ?> blog-header no-image no-text">
			<?php endif; ?>
            <div class="container header-content">
              <div class="row">
              <?php if ( get_theme_mod('custom_logo') ) : 
                        $custom_logo_id = get_theme_mod( 'custom_logo' );
            		$image = wp_get_attachment_image_src( $custom_logo_id , 'full' );
              ?>
			    <div class="col-md-3 logo-image">
                    <a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url( $image[0] ); ?>"></a>
                </div>
			  <?php endif; ?>
			  <?php if ( display_header_text() && get_header_image() ) : ?>
                <div class="col-md-9 <?php if ( get_theme_mod( 'header_width' ) == 'narrow' ) : ?>narrow<?php else: ?>full-width<?php endif; ?> header-text true has-image">
              <?php elseif ( display_header_text() && !get_header_image() ) : ?>
                <div class="col-md-9 <?php if ( get_theme_mod( 'header_width' ) == 'narrow' ) : ?>narrow<?php else: ?>full-width<?php endif; ?> header-text true no-image">
              <?php elseif ( !display_header_text() && get_header_image() ) : ?>
                <div class="col-md-9 <?php if ( get_theme_mod( 'header_width' ) == 'narrow' ) : ?>narrow<?php else: ?>full-width<?php endif; ?> header-text false has-image">
	          <?php elseif ( !display_header_text() && !get_header_image() ) : ?>
                 <div class="col-md-9 <?php if ( get_theme_mod( 'header_width' ) == 'narrow' ) : ?>narrow<?php else: ?>full-width<?php endif; ?> header-text false no-image hidden">
              <?php endif; ?>
                <?php if ( display_header_text() ) : ?>
                <h1 class="blog-title">
                  <?php bloginfo( 'name' ); ?>
                </h1>
                <p class="lead blog-description<?php if ( get_header_image() ) : ?> has-image<?php endif; ?>">
                  <?php bloginfo( 'description' ); ?>
                </p>
                <?php else : ?>
                <h1 class="blog-title hidden">
                  <?php bloginfo( 'name' ); ?>
                </h1>
                <p class="lead blog-description hidden">
                  <?php bloginfo( 'description' ); ?>
                </p>
                <?php endif; ?>
              </div><!-- /.header-text -->
            </div><!-- /.row -->
          </div><!-- /.header-content -->
        </div><!-- /.blog-header -->
        </div><!-- /.header -->
        <?php endif; ?>    
		</header>